@@ -31,7 +31,7 @@
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #
 # $Author: Bear $ (last)
-# $Date: 2020-07-26 14:31:20 +0800 (週日, 26 七月 2020) $
+# $Date: 2020-07-26 14:31:20 +0800 (Sun, 26 Jul 2020) $
 # $Revision: 12425 $
 """
 Distribution utilities.
@@ -383,31 +383,31 @@ def setup(name,
                    
     setuptoolsSetup(**kws)    
     
-    if 'bdist_wheel' in sys.argv:
-        print(("%s" % colored(
-            ("\n"
-             "---------------------------------------------------------"
-             "\n"
-             "Only 'sdist upload' and 'install' command will work properly."
-             "\n"
-             "\n"
-             "bdist_wheel not supported for this package. \n"
-             "If using egg install,\n"
-             "Some package would not be installed properly,\n"
-             "patch would not be executed either.\n"
-             "---------------------------------------------------------"
-             "\n"
-             "See more details: \n"
-             "https://code.nuwainfo.com/trac/mercurius/ticket/2646#comment:5"
-             "\n"
-             "https://code.nuwainfo.com/trac/mercurius/ticket/2643#comment:28"
-             "\n"
-             "https://code.nuwainfo.com/trac/Mercurius/ticket/2933#comment:25"
-             "\n"
-             "---------------------------------------------------------"
-             ), 'yellow', attrs=['bold'])
-        ))
-        raise NotImplementedError("bdist_wheel not supported for this package.")
+    # if 'bdist_wheel' in sys.argv:
+    #     print(("%s" % colored(
+    #         ("\n"
+    #          "---------------------------------------------------------"
+    #          "\n"
+    #          "Only 'sdist upload' and 'install' command will work properly."
+    #          "\n"
+    #          "\n"
+    #          "bdist_wheel not supported for this package. \n"
+    #          "If using egg install,\n"
+    #          "Some package would not be installed properly,\n"
+    #          "patch would not be executed either.\n"
+    #          "---------------------------------------------------------"
+    #          "\n"
+    #          "See more details: \n"
+    #          "https://code.nuwainfo.com/trac/mercurius/ticket/2646#comment:5"
+    #          "\n"
+    #          "https://code.nuwainfo.com/trac/mercurius/ticket/2643#comment:28"
+    #          "\n"
+    #          "https://code.nuwainfo.com/trac/Mercurius/ticket/2933#comment:25"
+    #          "\n"
+    #          "---------------------------------------------------------"
+    #          ), 'yellow', attrs=['bold'])
+    #     ))
+    #     raise NotImplementedError("bdist_wheel not supported for this package.")
     
     # patch
     if 'install' in sys.argv or 'bdist_wheel' in sys.argv:
